# <img width='280' src='https://user-images.githubusercontent.com/73984595/211105539-15db68ca-5bc8-4173-8327-cfcba1b5065b.svg'>

Crest is a web framework designed for simplicity and efficiency.  
To get started, read through the ```docs```. 
